<?php

/**
 * This is the model class for table "epicbbcode_bbcode".
 *
 * The followings are the available columns in table 'epicbbcode_bbcode':
 * @property integer $id
 * @property integer $active
 * @property string $find
 * @property string $replace
 * @property string $datetime_add
 * @property string $datetime_update
 *
 * The followings are the available model relations:
 * @property EpicbbcodeDescription[] $epicbbcodeDescriptions
 */
class Bbcode extends ActiveRecord {

    public $descriptionTitle;

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'epicbbcode_bbcode';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('active, find, replace', 'required'),
            array('active', 'numerical', 'integerOnly' => true),
            array('find, replace', 'length', 'max' => 255),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, active, find, replace, datetime_add, datetime_update,descriptionTitle', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
                'Description' => array(self::BELONGS_TO, 'Description', array('id' => 'bbcode_id')),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => Yii::t('BbCode', 'ID'),
            'active' => Yii::t('BbCode', 'Active'),
            'find' => Yii::t('BbCode', 'Find'),
            'replace' => Yii::t('BbCode', 'Replace with'),
            'datetime_add' => Yii::t('BbCode', 'Datetime Add'),
            'datetime_update' => Yii::t('BbCode', 'Datetime Update'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->alias = 'bbcode';
        $criteria->with = 'Description';
        $criteria->compare('id', $this->id);
        $criteria->compare('active', $this->active);
        $criteria->compare('find', $this->find, true);
        $criteria->compare('replace', htmlspecialchars($this->replace), true);
        $criteria->compare('Description.title', $this->descriptionTitle, true);
        $criteria->compare('datetime_add', $this->datetime_add, true);
        $criteria->compare('datetime_update', $this->datetime_update, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    public static function renderText($text) {
        $findBbCode = Bbcode::model()->findAll('active = 1');
        $find = array();
        $findParams = array();
        $replace = array();
        $count_replace = 0;

        foreach ($findBbCode as $bbcode) {
            $explode = explode(' {
            ', $bbcode->find);
            preg_match_all("~\{(.*?)}~s", $bbcode->find, $match_find);
            foreach ($match_find[0] as $key => $replace_repleae_str) {
                $count_replace = $count_replace + 1;
                $bbcode->find = str_replace($match_find[0][$key], "(.*?)", $bbcode->find);
                $bbcode->replace = str_replace($match_find[0][$key], "$$count_replace", $bbcode->replace);
            }
            $count_replace = 0;
            $bbcode->find = str_replace(']', '\]', $bbcode->find);
            $bbcode->find = str_replace('[', '\[', $bbcode->find);
            array_push($find, '~' . $bbcode->find . '~s');
            array_push($replace, $bbcode->replace);
        }
// Replacing the BBcodes with corresponding HTML tags
        echo preg_replace($find, $replace, $text);
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Bbcode the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
