<?php

/**
 * This is the model class for table "epicbbcode_description".
 *
 * The followings are the available columns in table 'epicbbcode_description':
 * @property integer $id
 * @property string $lang
 * @property integer $bbcode_id
 * @property string $title
 * @property string $short_description
 * @property string $long_description
 * @property string $datetime_add
 * @property string $datetime_update
 *
 * The followings are the available model relations:
 * @property EpicbbcodeBbcode $bbcode
 */
class Description extends ActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'epicbbcode_description';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('lang, title, short_description, long_description', 'required'),
            array('bbcode_id', 'numerical', 'integerOnly' => true),
            array('lang', 'length', 'max' => 2),
            array('title', 'length', 'max' => 128),
            array('short_description', 'length', 'max' => 255),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, lang, bbcode_id, title, short_description, long_description, datetime_add, datetime_update', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'bbcode' => array(self::BELONGS_TO, 'BbCode', 'bbcode_id'),
            'bbcodeByActive' => array(self::BELONGS_TO, 'BbCode', 'bbcode_id', 'condition' => 'bbcode.active=1'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'lang' => 'Lang',
            'bbcode_id' => 'Bbcode',
            'title' => 'Title',
            'short_description' => 'Short Description',
            'long_description' => 'Long Description',
            'datetime_add' => 'Datetime Add',
            'datetime_update' => 'Datetime Update',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('lang', $this->lang, true);
        $criteria->compare('bbcode_id', $this->bbcode_id);
        $criteria->compare('title', $this->title, true);
        $criteria->compare('short_description', $this->short_description, true);
        $criteria->compare('long_description', $this->long_description, true);
        $criteria->compare('datetime_add', $this->datetime_add, true);
        $criteria->compare('datetime_update', $this->datetime_update, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Description the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
